@@ -3,5 +3,6 @@ from .constants import *
 from .models import *
 from .repositories import *
 from .s3_downloader import JobArtifactsDownloader
-from .s3_uploader import S3ProjectFileUploader, S3WorkspaceDirectoryUploader, ZipArchiver
+from .s3_uploader import ExperimentFileUploader, ExperimentWorkspaceDirectoryUploader
+from .archivers import ZipArchiver
 from .sdk_exceptions import *
